:mod:`lck.django.common.models`
===============================


.. automodule:: lck.django.common.models


Classes
--------

.. autoclass:: Named
   :show-inheritance:
   :members:
   

.. autoclass:: Titled
   :show-inheritance:
   :members:
   

.. autoclass:: Slugged
   :show-inheritance:
   :members:
   

.. autoclass:: TimeTrackable
   :show-inheritance:
   :members:
   

.. autoclass:: Localized
   :show-inheritance:
   :members:
   

.. autoclass:: MonitoredActivity
   :show-inheritance:
   :members:
   

.. autoclass:: DisplayCounter
   :show-inheritance:
   :members:
   

.. autoclass:: SoftDeletable
   :show-inheritance:
   :members:
   

.. autoclass:: ViewableSoftDeletableManager
   :show-inheritance:
   :members:


.. autoclass:: MassMailer
   :show-inheritance:
   :members:
